Installation
------------

Install via ``pip``
^^^^^^^^^^^^^^^^^^^
You can install the latest release of PyEHM on PyPI by using:

.. code::

    python -m pip install pyehm

Install from source
^^^^^^^^^^^^^^^^^^^

To install the latest version from the GitHub repository:

.. code::

    python -m pip install git+https://github.com/sglvladi/pyehm#egg=pyehm


Development
^^^^^^^^^^^
If you are looking to carry out development on PyEHM, you should first clone from GitHub and install with development
dependencies by doing the following:

.. code::

    git clone "https://github.com/sglvladi/pyehm"
    cd pyehm
    python -m pip install -e .[dev]